#!/bin/bash
#
# source: http://web.mit.edu/kerberos/dist/krb5/1.6/krb5-1.6.3-signed.tar
#
# maintainer: gmg (g.monpontet@gmail.fr)
#

#------------------Set Some Variables

soft="krb5"
softversion="1.6.3"
packageversion="62.1"

arch="i486"
cpu="i686"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion/src"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
rm -f $dest.tgz
rm -rf $dest
tar -xvzf $srcpkg

#------------------Set correct permissions

cd $src

cat $buildir/krb5-CVE-2008-0062,0063.patch | patch -p1 --verbose
cat $buildir/krb5-CVE-2008-0947.patch | patch -p1 --verbose
cat $buildir/krb5-CVE-2007-5901.patch | patch -p1 --verbose
cat $buildir/krb5-CVE-2007-5971.patch | patch -p1 --verbose
cat $buildir/krb5-CVE-2009-0844-0845-2.patch | patch -p2 --verbose
cat $buildir/krb5-CVE-2009-0846.patch | patch -p2 --verbose
cat $buildir/krb5-CVE-2009-0847.patch | patch -p2 --verbose

chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;

#------------------Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
    --prefix=/usr \
    --sysconfdir=/etc \
    --enable-shared

make
make install DESTDIR=$dest

mkdir $dest/etc
cp -a  $dest/usr/share/examples/krb5/krb5.conf  $dest/etc/krb5.conf.new

#-----------------Strip executables 

( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "current ar archive" | cut -f 1 -d : | xargs strip -g 2> /dev/null
)

find $dest/usr/man -type f -exec gzip -9 {} \;

#-----------------Copy the documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp $buildir/$soft-$softversion/README $dest/usr/doc/$soft-$softversion

#----------------- Make the slack-desc files

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

    |-----handy-ruler----------------------------------------------------------|
krb5: krb5 - is a MIT Kerberos network authentication protocol
krb5:
krb5: Kerberos is a network authentication protocol. It is designed to provide
krb5: strong authentication for client/server applications by using secret-key
krb5: cryptography. A free implementation of this protocol is available from
krb5: from MIT.
krb5:
krb5:
krb5:
krb5:
krb5:
EODESC

cat << "DOINST" > $dest/install/doinst.sh
#!/bin/sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

config etc/krb5.conf.new
DOINST

#-----------------Put the Zen-build in the right directory

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-----------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz
makepkg -l y -c n $dest.tlz
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.txz > $package.md5
